@@ -9,19 +9,27 @@ class _GlobalState:
         if 'max_bars' not in self.__shared_state:
             self.set_defaults()
 
-    def set_defaults(self, debug_logging=None, raise_on_errors=None, max_bars=None, log=None):
+    def set_defaults(self,
+                     debug_logging=None,
+                     raise_on_errors=None,
+                     max_bars=None,
+                     log=None,
+                     return_as_dict=None,
+                     ):
         # self.convert_namedtuples_to_dict = False
         self.debug_logging = debug_logging or False
         self.raise_on_errors = raise_on_errors or False
         self.max_bars = max_bars or 100_000
         self.logger = log or print
+        self.return_as_dict = return_as_dict or False
 
     def get_state(self):
         state = dict(
             debug_logging=self.debug_logging,
             raise_on_errors=self.raise_on_errors,
             max_bars=self.max_bars,
-            log=self.logger
+            log=self.logger,
+            return_as_dict=self.return_as_dict
         )
         return state
 
